Skip to contents

A dataset containing simulated metric data for package examples. This example is for four population metrics corresponding to different areas.

Usage

annual_by_area

Format

A data frame with 25 rows and 5 variables:

year

A vector of years.

Narnia

A vector of random numbers.

Westeros

A vector of random numbers.

Wakanda

A vector of random numbers.

Arrakis

A vector of random numbers.

Simulated data