Monthly multi metric formatted example data
monthly_data_formatted.RdA list object containing simulated metric data for package examples. This example is for a monthly multi metric indicator (a vector of random numbers). This has been prepped using the data_prep function, for use with IEAnalyzeR's plotting function.