Skip to contents

A dataset containing simulated metric data for package examples. This example is for four population metrics corresponding to different areas.

Usage

twocat_data_formatted

Format

A multi-indicator data frame with data in two main categories:

year

A vector of years.

rev_narnia

A vector of random numbers.

count_narnia

A vector of random numbers.

rev_wakanda

A vector of random numbers.

count_wakanda

A vector of random numbers.

Simulated data