Title
create_metric_code_file.RdThis function creates a file within the Gulf IEA repo framework. This file outlines how you should code a metric that will be included in Gulf IEA ESR's and associated products. Should only be used within a repo created from the "ESR-Report-Template".
Arguments
- metric_root_name
The official root name of the metric to be coded.
- format
The filetype you would like created to code your metric. R or QMD files are supported.
- data_type
The type of accessibility of your data. Automated data are those that come from sources like APIs, non-automated data come from manually acquiring the data through csvs etc., and confidential data are those should not be hosted anywhere publically.