Count and revenue data per region
twocat_data_formatted.RdA dataset containing simulated metric data for package examples. This example is for four population metrics corresponding to different areas.
twocat_data_formatted.RdA dataset containing simulated metric data for package examples. This example is for four population metrics corresponding to different areas.